.. _require_opkg_module:

:mod:`fabtools.require.opkg`
----------------------------

.. automodule:: fabtools.require.opkg

    .. seealso:: :ref:`opkg_module`

    Packages
    ~~~~~~~~

    .. autofunction:: package
    .. autofunction:: packages
    .. autofunction:: nopackage
    .. autofunction:: nopackages
